pub enum BroadcastMessage {
Chat(String),
PlayerJoinedInfo(PlayerJoinInfo),
PlayerLeft(u128),
Shutdown,
}Expand description
BroadcastMessage gets broadcasted from the server thread to all the plot threads.
This happens when there is a chat message, a player joins or leaves, or the server
shuts down.
Variants
Chat(String)
This message is broadcasted for chat messages. It contains the raw json data to send to the clients.
PlayerJoinedInfo(PlayerJoinInfo)
This message is broadcasted when a player joins the server. It is used to update the tab-list on all connected clients.
PlayerLeft(u128)
This message is broadcasted when a player leaves the server. It is used to update the tab-list on all connected clients.
Shutdown
This message is broadcasted when the server is stopping, either through the stop command or through the ctrl+c handler.